@@ -126,7 +126,9 @@ class Field:
         # w.r.t. undeformed coordinates "J" evaluated at quadrature point "p"
         # for each cell "e"
         g = np.einsum(
-            "ea...,aJpe->...Jpe", self.values[self.region.mesh.cells], self.region.dhdX,
+            "ea...,aJpe->...Jpe",
+            self.values[self.region.mesh.cells],
+            self.region.dhdX,
         )
 
         if sym:
