@@ -61,6 +61,14 @@ class Mesh:
             self.points_without_cells = np.array([], dtype=int)
             self.points_with_cells = np.arange(self.npoints)
 
+    def as_discontinous(self):
+        "Return a new instance of a Mesh with disconnected cells."
+
+        points = self.points[self.cells].reshape(-1, self.dim)
+        cells = np.arange(self.cells.size).reshape(*self.cells.shape)
+
+        return Mesh(points, cells, cell_type=self.cell_type)
+
     def save(self, filename="mesh.vtk"):
         "Export mesh as VTK file."
 
