@@ -71,7 +71,11 @@ def test_solve_check():
     fe.tools.save(r, u)
     fe.tools.save(r, u, r=b)
     fe.tools.save(
-        r, u, r=b, F=F, gradient=W.gradient(F),
+        r,
+        u,
+        r=b,
+        F=F,
+        gradient=W.gradient(F),
     )
 
     force = fe.tools.force(u, b, bounds["symx"])
@@ -80,6 +84,14 @@ def test_solve_check():
     for a in [2, 3, 4, 5]:
         curve = fe.tools.curve(np.arange(a), np.ones(a) * force[0])
 
+    s = fe.math.dot(W.gradient(F), fe.math.inv(fe.math.cof(F)))
+
+    cauchy = fe.tools.project(fe.math.tovoigt(s), region=r, average=True)
+    assert cauchy.shape == (r.mesh.npoints, 6)
+
+    cauchy = fe.tools.project(fe.math.tovoigt(s), region=r, average=False)
+    assert cauchy.shape == (r.mesh.cells.size, 6)
+
 
 def test_solve_mixed_check():
 
@@ -118,7 +130,12 @@ def test_solve_mixed_check():
     fe.tools.save(r, f, unstack=unstack)
     fe.tools.save(r, f, r=b, unstack=unstack)
     fe.tools.save(
-        r, f, r=b, unstack=unstack, F=F, gradient=W_mixed.gradient(F, p, J),
+        r,
+        f,
+        r=b,
+        unstack=unstack,
+        F=F,
+        gradient=W_mixed.gradient(F, p, J),
     )
 
     force = fe.tools.force(u, b, bounds["symx"], unstack=unstack)
